package sun.management;

import javax.management.openmbean.OpenType;
import javax.management.openmbean.ArrayType;
import javax.management.openmbean.TabularType;
import java.util.Set;
import java.io.ObjectStreamException;
import java.util.Collection;
import javax.management.openmbean.CompositeType;
import java.io.Serializable;
import javax.management.openmbean.CompositeData;

public abstract class LazyCompositeData implements CompositeData, Serializable
{
    private CompositeData compositeData;
    private static final long serialVersionUID = -2190411934472666714L;
    
    public LazyCompositeData() {
    }
    
    @Override
    public boolean containsKey(String s) {
        return this.compositeData().containsKey(s);
    }
    
    @Override
    public boolean containsValue(Object o) {
        return this.compositeData().containsValue(o);
    }
    
    @Override
    public boolean equals(Object o) {
        return this.compositeData().equals(o);
    }
    
    @Override
    public Object get(String s) {
        return this.compositeData().get(s);
    }
    
    @Override
    public Object[] getAll(String[] array) {
        return this.compositeData().getAll(array);
    }
    
    @Override
    public CompositeType getCompositeType() {
        return this.compositeData().getCompositeType();
    }
    
    @Override
    public int hashCode() {
        return this.compositeData().hashCode();
    }
    
    @Override
    public String toString() {
        return this.compositeData().toString();
    }
    
    @Override
    public Collection<?> values() {
        return this.compositeData().values();
    }
    
    private synchronized CompositeData compositeData() {
        if (this.compositeData != null) {
            return this.compositeData;
        }
        return this.compositeData = this.getCompositeData();
    }
    
    protected Object writeReplace() throws ObjectStreamException {
        return this.compositeData();
    }
    
    protected abstract CompositeData getCompositeData();
    
    static String getString(CompositeData compositeData, String s) {
        if (compositeData == null) {
            throw new IllegalArgumentException("Null CompositeData");
        }
        return (String)compositeData.get(s);
    }
    
    static boolean getBoolean(CompositeData compositeData, String s) {
        if (compositeData == null) {
            throw new IllegalArgumentException("Null CompositeData");
        }
        return (boolean)compositeData.get(s);
    }
    
    static long getLong(CompositeData compositeData, String s) {
        if (compositeData == null) {
            throw new IllegalArgumentException("Null CompositeData");
        }
        return (long)compositeData.get(s);
    }
    
    static int getInt(CompositeData compositeData, String s) {
        if (compositeData == null) {
            throw new IllegalArgumentException("Null CompositeData");
        }
        return (int)compositeData.get(s);
    }
    
    protected static boolean isTypeMatched(CompositeType compositeType, CompositeType compositeType2) {
        if (compositeType == compositeType2) {
            return true;
        }
        Set<String> keySet = compositeType.keySet();
        return compositeType2.keySet().containsAll(keySet) && keySet.stream().allMatch(s/* java.lang.String, */ -> isTypeMatched(p0.getType(s), p1.getType(s)));
    }
    
    protected static boolean isTypeMatched(TabularType tabularType, TabularType tabularType2) {
        return tabularType == tabularType2 || (tabularType.getIndexNames().equals(tabularType2.getIndexNames()) && isTypeMatched(tabularType.getRowType(), tabularType2.getRowType()));
    }
    
    protected static boolean isTypeMatched(ArrayType<?> arrayType, ArrayType<?> arrayType2) {
        return arrayType == arrayType2 || (arrayType.getDimension() == arrayType2.getDimension() && isTypeMatched(arrayType.getElementOpenType(), arrayType2.getElementOpenType()));
    }
    
    private static boolean isTypeMatched(OpenType<?> openType, OpenType<?> openType2) {
        if ((openType instanceof CompositeType)) {
            if (!(openType2 instanceof CompositeType)) {
                return false;
            }
            if (!isTypeMatched((CompositeType)openType, (CompositeType)openType2)) {
                return false;
            }
        }
        else if ((openType instanceof TabularType)) {
            if (!(openType2 instanceof TabularType)) {
                return false;
            }
            if (!isTypeMatched((TabularType)openType, (TabularType)openType2)) {
                return false;
            }
        }
        else if ((openType instanceof ArrayType)) {
            if (!(openType2 instanceof ArrayType)) {
                return false;
            }
            if (!isTypeMatched((ArrayType)openType, (ArrayType)openType2)) {
                return false;
            }
        }
        else if (!openType.equals(openType2)) {
            return false;
        }
        return true;
    }
}
